@@ -12,7 +12,7 @@
 ##############################################################################
 """Request log profiler script
 
-$Id: requestprofiler.py 110405 2010-04-01 16:13:15Z tseaver $
+$Id: requestprofiler.py 124568 2012-03-11 16:44:05Z tseaver $
 """
 import sys, time, getopt, math, cPickle
 from types import StringType
@@ -814,7 +814,7 @@ def main():
         elif mode=='urlfocus':
             sortf = Sort('start', ascending=1)
         else:
-            raise 'Invalid mode'
+            raise ValueError('Invalid mode')
 
         req=get_requests(files, start, end, statsfname, writestats, readstats)
         analyze(req, top, sortf, start, end, mode, resolution, urlfocusurl,
